/*
 * (c) COPYRIGHT 1999 World Wide Web Consortium
 * (Massachusetts Institute of Technology, Institut National de Recherche
 *  en Informatique et en Automatique, Keio University).
 * All Rights Reserved. http://www.w3.org/Consortium/Legal/
 *
 * $Id: SimpleSelector.java,v 1.2 1999/09/30 16:54:22 plehegar Exp $
 */
package org.w3c.css.sac;

/**
 * This interface is only for constraints on selectors.
 *
 * <p>A <code>ConditionalSelector</code> can only accept a simple selector or a
 * negative selector.</p>
 *
 * @version $Revision: 1.2 $
 * @author Philippe Le Hegaret */
public interface SimpleSelector extends Selector {
    // empty
}
